# Security Policy

## Supported Versions


| Version | Supported          |
| ------- | ------------------ |
| 1.x   | :white_check_mark: |


## Reporting a Vulnerability

Please report any security vulnerabilities to amauri@tarteaucitron.io
I'll get back to you within 24 hours and fix the issue asap.
